==> qmmp-0.12.14.tar.bz2: qmmp-0.12.14/src/plugins/General/history/dateinputdialog.h <==
/***************************************************************************
 *   Copyright (C) 2017 by Ilya Kotov                                      *
 *   forkotov02@ya.ru                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef DATEINPUTDIALOG_H
#define DATEINPUTDIALOG_H

#include <QDialog>
#include <QDate>

namespace Ui {
class DateInputDialog;
}

class DateInputDialog : public QDialog
{
    Q_OBJECT

public:
    explicit DateInputDialog(QWidget *parent = 0);
    ~DateInputDialog();

    QDate selectedDate() const;
    void setSelectedDate(const QDate &date);

private:
    Ui::DateInputDialog *m_ui;
};

#endif // DATEINPUTDIALOG_H

==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/General/history/dateinputdialog.h <==
/***************************************************************************
 *   Copyright (C) 2017 by Ilya Kotov                                      *
 *   forkotov02@ya.ru                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef DATEINPUTDIALOG_H
#define DATEINPUTDIALOG_H

#include <QDialog>
#include <QDate>

namespace Ui {
class DateInputDialog;
}

class DateInputDialog : public QDialog
{
    Q_OBJECT

public:
    explicit DateInputDialog(QWidget *parent = nullptr);
    ~DateInputDialog();

    QDate selectedDate() const;
    void setSelectedDate(const QDate &date);

private:
    Ui::DateInputDialog *m_ui;
};

#endif // DATEINPUTDIALOG_H
